@@ -3,6 +3,7 @@ import os
 import logging
 
 from flask import Flask
+from flask.ext.cors import CORS
 
 from alerta.version import __version__
 
@@ -25,6 +26,8 @@ else:
     app.logger.addHandler(stderr_handler)
     app.logger.setLevel(logging.INFO)
 
+cors = CORS(app)
+
 app.logger.info('Starting alerta version %s ...', __version__)
 
 from alerta.app.database import Mongo
